@@ -1,8 +1,8 @@
 package Log::Log4perl::Appender::Graylog;
 
 # ABSTRACT: Log dispatcher writing to udp Graylog server
-our $VERSION = '1.3'; # VERSION 1.3
-my $VERSION=1.3;
+our $VERSION = '1.4'; # VERSION 1.4
+my $VERSION=1.4;
 our @ISA = qw(Log::Log4perl::Appender);
 
 use strict;
@@ -12,6 +12,7 @@ use JSON -convert_blessed_universally;
 use Sys::Hostname;
 use Data::UUID;
 use POSIX qw(strftime);
+use IO::Compress::Gzip qw( gzip $GzipError );
 use IO::Socket;
 use Data::DTO::GELF;
 
@@ -30,6 +31,7 @@ sub new {
         name     => "unknown name",
         PeerAddr => "",
         PeerPort => "",
+        Gzip => 1,
         %params,
     };
 
@@ -62,7 +64,16 @@ sub log {
         Type     => SOCK_DGRAM,
         Proto    => 'udp'
     ) or die "Socket error";
-    $socket->send( $j_packet . "\n" );
+
+    if($self->{'Gzip'})
+    {
+        my $gzipped_message;
+        gzip \$j_packet =>  \$gzipped_message or die "gzip failed: $GzipError\n";
+        $socket->send( $gzipped_message . "\n" );
+    }else {
+        $socket->send( $j_packet . "\n" );
+    }
+    
 
     $socket->close();
 
@@ -82,7 +93,7 @@ Log::Log4perl::Appender::Graylog - Log dispatcher writing to udp Graylog server
 
 =head1 VERSION
 
-version 1.3
+version 1.4
 
 =head1 SYNOPSIS
 
@@ -91,6 +102,7 @@ version 1.3
     my $appender = Log::Log4perl::Appender::Graylog->new(
       PeerAddr => "glog.foo.com",
       PeerPort => 12209,
+      Gzip => 1, # Glog2 usually requires gzip but can send plain text
     );
  
     $appender->log(message => "Log me\n");
